# Table of Contents

- [dashboard-modeling](<./dashboard-modeling.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Dashboard Modeling](<./Dashboard-Modeling.md>)
  - [Overview](<./Dashboard-Modeling/Overview.md>)
  - [Stakeholder Management, Team Dashboards, and Persona Dashboard](<./Dashboard-Modeling/Stakeholder-Management-Team-Dashboards-and-Persona-Dashboard.md>)
  - [Call-to-Action with Regards to Use Cases](<./Dashboard-Modeling/Call-to-Action-with-Regards-to-Use-Cases.md>)
  - [Deliverables](<./Dashboard-Modeling/Deliverables.md>)
  - [Was this page helpful?](<./Dashboard-Modeling/Was-this-page-helpful.md>)
